History
=======

This module was extracted from FoFiX, and was inspired from `Performous`_.

First, it was a pure-Python script named `PitchAnalyzer`_. This script is available in the version 3 of FoFiX.

To speed up this FoFiX, this script were `adapted in C++`__ in the version 4.


.. _Performous: https://performous.org
.. _PitchAnalyzer: https://github.com/fofix/fofix/blob/v3.122/src/PitchAnalyzer.py
__ https://github.com/fofix/fofix/commit/40f33fa67bac028f3245ace050356bad6f211edc

